@@ -42,6 +42,7 @@ class MainWindow(QtGui.QMainWindow):
             self.falschsound="/opt/quizzynator/falsch.wav"
             self.gameoversound="/opt/quizzynator/gameover.wav"
             self.rankupsound="/opt/quizzynator/rankup.wav"
+			self.savegame="/home/user/MyDocs/.Quizzynator/quizzynator.db"
            
             #self.fragenkatalog="/home/user/MyDocs//fragenkatalog.py"      
             self.highscoredatenbank="/home/user/MyDocs/.QuizzyNator/highscores.db"
@@ -91,10 +92,10 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.back_2.clicked.connect(self.back_2)
         self.ui.back_3.clicked.connect(self.back_2)
         self.ui.back_4.clicked.connect(self.back_2)
-        #self.ui.updater.clicked.connect(self.update)
-        #self.ui.search.clicked.connect(self.search)
+        self.ui.updater.clicked.connect(self.update)
+        self.ui.search.clicked.connect(self.search)
         self.ui.sound.toggled.connect(self.sound)
-        #self.ui.start_update.clicked.connect(self.updating)
+        self.ui.start_update.clicked.connect(self.updating)
         self.ui.vollbild.toggled.connect(self.vollbild)
         self.ui.hochformat.toggled.connect(self.format)
         self.ui.nextquest.clicked.connect(self.choose_frage)
@@ -156,8 +157,8 @@ class MainWindow(QtGui.QMainWindow):
     
     def spielladen(self):
 #Gespeichertes Spiel laden
-        if os.path.isfile("quizzynator.db"):
-            if os.lstat("quizzynator.db").st_size>0:
+        if os.path.isfile(self.savegame):
+            if os.lstat(self.savegame).st_size>0:
                 self.load_user()
                 self.ui.stackedWidget.setCurrentIndex(2)                 
             else:
@@ -364,7 +365,7 @@ class MainWindow(QtGui.QMainWindow):
         
     def load_user(self):
         userdata={}
-        fobj=open("quizzynator.db","r")
+        fobj=open(self.savegame,"r")
         for line in fobj:
             zuordnung=line.split()
             userdata[zuordnung[0]]=zuordnung[1]
@@ -388,7 +389,7 @@ class MainWindow(QtGui.QMainWindow):
 #Ein klick auf X zeigt keine wirkung
         playername=self.ui.playername.text()
      
-        default=open("quizzynator.db","w")
+        default=open(self.savegame,"w")
                
         userdata={"Spielername":str(playername),
                   "Score":str(self.score),
@@ -429,8 +430,6 @@ class MainWindow(QtGui.QMainWindow):
                 self.ui.highscoreanzeige.setText(self.scores)   
         self.ui.stackedWidget.setCurrentIndex(7)        
             
-           
-       
        
     def minimizefunc(self):#Experimentell, schließt statt zu minimieren
         subprocess.Popen(['dbus-send', '--type=signal', '--session', '/com/nokia/hildon_desktop', 'com.nokia.hildon_desktop.exit_app_view'])        
@@ -487,6 +486,7 @@ class MainWindow(QtGui.QMainWindow):
         
     def craveobrowser(self):
         webbrowser.open("http://www.craveo.de")
+		
 #Möglichkeit, eigene Fragen einzureichen       
     def fragen_einreichen(self):
         self.ui.stackedWidget.setCurrentIndex(5)
